/*********************************************************************************
*	 FileName:  PASSLIB.cpp		                                         *
*  Module:  	Main Module for PASS Library DLL.                                *
*  Version:		0.0                                                      *
*  Date:			12/13/93                                         *
*  Author:		L. Allen                                                 *
*                                                                                *
*  Update History                                                                *
*                                                                                *
*  update    ver   description (author)                                          *
*  -------   ---   -----------                                                   *
*  9312.13   0.0   Work begun. (LA)                                              *
*                                                                                *
*	 Description:                                                            *
*                                                                                *
*  This module contains the LibMain function and interrupt handler for the Pass  *
*  DLL.                                                                          *
*                                                                                *
**********************************************************************************/
#include <stdlib.h>
#include <string.h>
#include <owl.h>
#include <windows.h>
#include "device.h"
#include "msgwin.h"
#include "passlib.h"

#define PT_TIMERH 0x33
#define PT_TIMERM 0x32
#define PT_TIMERL 0x31
#define PI_MFTPTR 0x400



static PTModule PASSLIB;
static PTWindowsObject parentwin;
static TDevice *monitor;
static TDevice *brm;
static TMsgWin *msgwin;
extern unsigned _WinAllocFlag;

int FAR PASCAL LibMain(HINSTANCE hInstance, WORD, WORD, LPSTR lpCmdLine)
 {
   int TheStatus;

   _WinAllocFlag = GMEM_SHARE;
   PASSLIB = new TModule("PASSLIB", hInstance, lpCmdLine);
   TheStatus = PASSLIB->Status;
   if ( TheStatus != 0 )
   {
    delete PASSLIB;
    PASSLIB = NULL;
   }
   monitor = NULL;
   brm = NULL;
   return (TheStatus == 0);
 }

int FAR PASCAL WEP ( int /*bSystemExit*/ )
{
    return 1;
}

void far _export InitMonitor(HWND ParentHWnd, WORD IO, WORD MEMBASE, 
                             WORD INTLEVEL)
 {
   parentwin = PASSLIB->GetParentObject(ParentHWnd);
   monitor = new TDevice(parentwin,IO,MEMBASE,INTLEVEL);
  }

void far _export CloseMonitor(void)
 {
   delete monitor;
 }

void far _export MonitorAll(void)
 {
  WORD RTndx, SAndx, row, col;
  if((monitor != NULL)&&(monitor->DeviceOk))
  {
   for(row=0;row<=3;row++)
   {
     for(col=0;col<=7;col++)
      {
       // Clear all filter bits for RT
   
       RTndx = row*8 + col;
       for(SAndx=0;SAndx<= 3;SAndx++)
         monitor->pr(PI_MFTPTR+(RTndx*4 + SAndx), 0xFFFF);
       }
    }
  }
 }
void far _export SetMonitorClock(int day, int hour, int min, int sec)
 {
   WORD  TimerH, TimerM;

  if((monitor != NULL)&&(monitor->DeviceOk))
  {
   // Load high and low timer words
   TimerH = (day * 0x20);
   TimerH = TimerH | hour;
   TimerM = (min & 0x003F) << 10;
   TimerM = TimerM | (((sec & 0x003F) << 4) & 0xFFF0);

   // Inable IO register access
   monitor->pr(0,(monitor->gr(0) & 0xFEFF));

   //Inable clock write
   monitor->pr(PT_TIMERL,4);

   //Set Clock to days, hours,minutes, and seconds }
   monitor->pr(PT_TIMERM,TimerM);
   monitor->pr(PT_TIMERH,TimerH);

   // Restart Timer 
   monitor->pr(PT_TIMERL,1);

   // Disable IO
   monitor->pr(0,(monitor->gr(0) | 0x100));
  }
 }

WORD far _export MGR(WORD adr)
 {
  if(monitor != NULL)
  {
    return monitor->gr(adr);
  }
  else
    return 0xffff;
 }

void far _export MPR(WORD adr,WORD val)
 {
  if(monitor != NULL)
    monitor->pr(adr,val);
 }

BOOL far _export StartUC(void)
 {
  if((monitor != NULL)&&(monitor->DeviceOk))
    return (monitor->start_uc());
  else
    return FALSE;
 }

void far _export StopUC(void)
 {
  if((monitor != NULL)&&(monitor->DeviceOk))
   (monitor->stop_uc());
 }

void far _export InitializeLog(FILE *SAVEFILE,long int FILESIZE)
 {
   BOOL temp;

   msgwin = new TMsgWin(parentwin,"",PASSLIB,monitor,SAVEFILE,FILESIZE);
   temp=(msgwin == PASSLIB->MakeWindow(msgwin));
   //msgwin->Show(SW_HIDE);

   PostMessage(msgwin->HWindow, WM_USER+150,0,0);


 }
